==> c2cgeoportal_geoportal-2.5.post20190529-py2.py3-none-any.whl: tests/test_headerstween.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2018-2019, Camptocamp SA
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

# The views and conclusions contained in the software and documentation are those
# of the authors and should not be interpreted as representing official policies,
# either expressed or implied, of the FreeBSD Project.

# pylint: disable=missing-docstring,attribute-defined-outside-init,protected-access


import pyramid.registry
from unittest import TestCase
from pyramid.testing import DummyRequest


def handler(request):
    return request.response


class MyRequest(DummyRequest):
    def __init__(self, path_info):
        self.path_info = path_info


class TestCacheBuster(TestCase):

    @classmethod
    def setup_class(cls):
        pass

    def test_tween(self):
        from c2cgeoportal_geoportal.lib.headers import HeadersTween

        registry = pyramid.registry.Registry()
        registry.settings = {
            'global_headers': [{
                'pattern': '^/test/.*',
                'headers': {
                    'X-Test': 'TOTO'
                }
            }]
        }
        ht = HeadersTween(handler, registry)

        request = MyRequest("/test/titi")
        response = ht(request)
        assert response.headers['X-Test'] == 'TOTO'

        request = MyRequest("/test2/titi")
        response = ht(request)
        assert 'X-Test' not in response.headers

==> c2cgeoportal_geoportal-2.5.0.51-py2.py3-none-any.whl: tests/test_headerstween.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2018-2019, Camptocamp SA
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

# The views and conclusions contained in the software and documentation are those
# of the authors and should not be interpreted as representing official policies,
# either expressed or implied, of the FreeBSD Project.

# pylint: disable=missing-docstring,attribute-defined-outside-init,protected-access


from unittest import TestCase

import pyramid.registry

from tests import DummyRequest


def handler(request):
    return request.response


class MyRequest(DummyRequest):
    def __init__(self, path_info):
        self.path_info = path_info


class TestCacheBuster(TestCase):
    @classmethod
    def setup_class(cls):
        pass

    def test_tween(self):
        from c2cgeoportal_geoportal.lib.headers import HeadersTween

        registry = pyramid.registry.Registry()
        registry.settings = {"global_headers": [{"pattern": "^/test/.*", "headers": {"X-Test": "TOTO"}}]}
        ht = HeadersTween(handler, registry)

        request = MyRequest("/test/titi")
        response = ht(request)
        assert response.headers["X-Test"] == "TOTO"

        request = MyRequest("/test2/titi")
        response = ht(request)
        assert "X-Test" not in response.headers
